import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.app.qt.save_data is deprecated, use glue_qt.app.save_data instead', GlueDeprecationWarning)
from glue_qt.app.save_data import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.viewers.custom.qt.custom_viewer is deprecated, use glue_qt.viewers.custom.custom_viewer instead', GlueDeprecationWarning)
from glue_qt.viewers.custom.custom_viewer import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.dialogs.data_wizard.qt.data_wizard_dialog is deprecated, use glue_qt.dialogs.data_wizard.data_wizard_dialog instead', GlueDeprecationWarning)
from glue_qt.dialogs.data_wizard.data_wizard_dialog import *  # noqa



from glue.viewers.common.viewer import Viewer
from glue.viewers.histogram.state import HistogramViewerState
from glue.core.application_base import Application
from glue.core.data import Data


class TestHistogramViewer(Viewer):
    _state_cls = HistogramViewerState


def test_remove_data_collection():

    # Regression test for a bug that caused an IncompatibleAttribute
    # error when updating the number of bins in a histogram after
    # removing a dataset from the DataCollection (this was due to
    # a caching issue)

    data1 = Data(x=[1, 2, 3], label='data1')
    data2 = Data(y=[1, 2, 3], label='data2')

    app = Application()
    app.data_collection.append(data1)
    app.data_collection.append(data2)

    viewer = app.new_data_viewer(TestHistogramViewer)
    viewer.add_data(data1)
    viewer.add_data(data2)

    viewer.state.hist_n_bin = 30

    app.data_collection.remove(data1)

    viewer.state.hist_n_bin = 20


def test_incompatible_datasets():

    # Regression test for a bug that caused an IncompatibleAttribute
    # error when changing the dataset used in the histogram viewer to one that
    # is not linked to the first dataset.

    data1 = Data(x=[1, 2, 3], label='data1')
    data2 = Data(y=[1, 2, 3], label='data2')

    app = Application()
    app.data_collection.append(data1)
    app.data_collection.append(data2)

    viewer = app.new_data_viewer(TestHistogramViewer)
    viewer.add_data(data1)
    viewer.add_data(data2)

    viewer.state.x_att = data1.id['x']

    viewer.state.hist_n_bin = 30

    viewer.state.x_att = data2.id['y']

    viewer.state.hist_n_bin = 20



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.core.qt.data_collection_model is deprecated, use glue_qt.core.data_collection_model instead', GlueDeprecationWarning)
from glue_qt.core.data_collection_model import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.utils.qt.mime is deprecated, use glue_qt.utils.mime instead', GlueDeprecationWarning)
from glue_qt.utils.mime import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.dialogs.link_editor.qt is deprecated, use glue_qt.dialogs.link_editor instead', GlueDeprecationWarning)
from glue_qt.dialogs.link_editor import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.dialogs.component_arithmetic.qt.component_arithmetic is deprecated, use glue_qt.dialogs.component_arithmetic.component_arithmetic instead', GlueDeprecationWarning)
from glue_qt.dialogs.component_arithmetic.component_arithmetic import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.app.qt.application is deprecated, use glue_qt.app.application instead', GlueDeprecationWarning)
from glue_qt.app.application import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.viewers.image.qt.profile_viewer_tool is deprecated, use glue_qt.viewers.image.profile_viewer_tool instead', GlueDeprecationWarning)
from glue_qt.viewers.image.profile_viewer_tool import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.dialogs.common.qt is deprecated, use glue_qt.dialogs.common instead', GlueDeprecationWarning)
from glue_qt.dialogs.common import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning

warnings.warn('Importing from glue.qglue is deprecated, use glue_qt.qglue instead', GlueDeprecationWarning)

from glue_qt.qglue import *  # noqa


def parse_data(*args, **kwargs):
    warnings.warn('glue.qglue.parse_data is deprecated, use glue.core.parsers.parse_data instead', GlueDeprecationWarning)
    from glue.core.parsers import parse_data
    return parse_data(*args, **kwargs)


def parse_links(*args, **kwargs):
    warnings.warn('glue.qglue.parse_links is deprecated, use glue.core.parsers.parse_links instead', GlueDeprecationWarning)
    from glue.core.parsers import parse_links
    return parse_links(*args, **kwargs)



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.core.qt.mime is deprecated, use glue_qt.core.mime instead', GlueDeprecationWarning)
from glue_qt.core.mime import *  # noqa
